==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm5/lib/PercentageVolumeOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { PercentageVolumeOscillatorIndicatorStrategy } from "./PercentageVolumeOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var PercentageVolumeOscillatorIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PercentageVolumeOscillatorIndicator, _super);
    function PercentageVolumeOscillatorIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PercentageVolumeOscillatorIndicator.prototype.get_yy = function () {
        return new PercentageVolumeOscillatorIndicatorStrategy();
    };
    Object.defineProperty(PercentageVolumeOscillatorIndicator.prototype, "yy", {
        get: function () {
            return this.get_yy();
        },
        enumerable: false,
        configurable: true
    });
    PercentageVolumeOscillatorIndicator.prototype.get_zb = function () {
        return PercentageVolumeOscillatorIndicator.$;
    };
    Object.defineProperty(PercentageVolumeOscillatorIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PercentageVolumeOscillatorIndicator.prototype, "shortPeriod", {
        get: function () {
            return typeGetValue(this.c(PercentageVolumeOscillatorIndicator.zk));
        },
        set: function (a) {
            this.h(PercentageVolumeOscillatorIndicator.zk, a);
        },
        enumerable: false,
        configurable: true
    });
    PercentageVolumeOscillatorIndicator.prototype.y6 = function () {
        return this.shortPeriod;
    };
    Object.defineProperty(PercentageVolumeOscillatorIndicator.prototype, "longPeriod", {
        get: function () {
            return typeGetValue(this.c(PercentageVolumeOscillatorIndicator.zj));
        },
        set: function (a) {
            this.h(PercentageVolumeOscillatorIndicator.zj, a);
        },
        enumerable: false,
        configurable: true
    });
    PercentageVolumeOscillatorIndicator.prototype.y3 = function () {
        return this.longPeriod;
    };
    PercentageVolumeOscillatorIndicator.$t = markType(PercentageVolumeOscillatorIndicator, 'PercentageVolumeOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    PercentageVolumeOscillatorIndicator.zk = StrategyBasedIndicator.zi(10, PercentageVolumeOscillatorIndicator.$);
    PercentageVolumeOscillatorIndicator.zj = StrategyBasedIndicator.ze(30, PercentageVolumeOscillatorIndicator.$);
    return PercentageVolumeOscillatorIndicator;
}(StrategyBasedIndicator));
export { PercentageVolumeOscillatorIndicator };

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/PercentageVolumeOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { PercentageVolumeOscillatorIndicatorStrategy } from "./PercentageVolumeOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var PercentageVolumeOscillatorIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PercentageVolumeOscillatorIndicator, _super);
    function PercentageVolumeOscillatorIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PercentageVolumeOscillatorIndicator.prototype.bj = function () {
        return new PercentageVolumeOscillatorIndicator();
    };
    PercentageVolumeOscillatorIndicator.prototype.get_abq = function () {
        return new PercentageVolumeOscillatorIndicatorStrategy();
    };
    Object.defineProperty(PercentageVolumeOscillatorIndicator.prototype, "abq", {
        get: function () {
            return this.get_abq();
        },
        enumerable: false,
        configurable: true
    });
    PercentageVolumeOscillatorIndicator.prototype.get_ab3 = function () {
        return PercentageVolumeOscillatorIndicator.$;
    };
    Object.defineProperty(PercentageVolumeOscillatorIndicator.prototype, "ab3", {
        get: function () {
            return this.get_ab3();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PercentageVolumeOscillatorIndicator.prototype, "shortPeriod", {
        get: function () {
            return typeGetValue(this.c(PercentageVolumeOscillatorIndicator.acc));
        },
        set: function (a) {
            this.h(PercentageVolumeOscillatorIndicator.acc, a);
        },
        enumerable: false,
        configurable: true
    });
    PercentageVolumeOscillatorIndicator.prototype.aby = function () {
        return this.shortPeriod;
    };
    Object.defineProperty(PercentageVolumeOscillatorIndicator.prototype, "longPeriod", {
        get: function () {
            return typeGetValue(this.c(PercentageVolumeOscillatorIndicator.acb));
        },
        set: function (a) {
            this.h(PercentageVolumeOscillatorIndicator.acb, a);
        },
        enumerable: false,
        configurable: true
    });
    PercentageVolumeOscillatorIndicator.prototype.abv = function () {
        return this.longPeriod;
    };
    PercentageVolumeOscillatorIndicator.$t = markType(PercentageVolumeOscillatorIndicator, 'PercentageVolumeOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    PercentageVolumeOscillatorIndicator.acc = StrategyBasedIndicator.aca(10, PercentageVolumeOscillatorIndicator.$);
    PercentageVolumeOscillatorIndicator.acb = StrategyBasedIndicator.ab6(30, PercentageVolumeOscillatorIndicator.$);
    return PercentageVolumeOscillatorIndicator;
}(StrategyBasedIndicator));
export { PercentageVolumeOscillatorIndicator };
